==> advanced-power-monitor-src_0.5.1-2.tar.gz: advanced-power-monitor-src-0.5.1/src/usr/src/advanced-power-monitor/modules/AbstractModules.py <==
'''
Advanced Power Abstract Module and its subclasses
2008-2009(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from Util import File, Shell, System
import time, os.path

class AbstractModule():

  def __init__(self):
    self.name = self.__class__.__name__
    self.interval = 1000
    self.value = None
    self.available = True
    self.async = False
    self.pre_init()
    self.available = self.available and self.check_available()
    if self.available:
      self.update()

  def pre_init(self):
    raise NotImplementedError("AbstractModule.pre_init() must be implemented")

  def check_available(self):
    raise NotImplementedError("AbstractModule.check_available() must be implemented")

  def update(self):
    raise NotImplementedError("AbstractModule.update() must be implemented")

  def process(self):
    raise NotImplementedError("AbstractModule.process() must be implemented")

  def get_name(self):
    return self.__class__.__name__

  def get_updated(self):
    self.update()
    return self.value

class AbstractModuleWithFileSource(AbstractModule):

  def __init__(self):
    self.file = ''
    AbstractModule.__init__(self)

  def check_available(self):
    return os.path.exists(self.file)

  def update(self):
    lines = File.get_lines(self.file)
    if lines:
      self.value = self.process(lines)

class AbstractModuleWithShellSource(AbstractModule):

  def __init__(self):
    self.command = ''
    AbstractModule.__init__(self)

  def check_available(self):
    return True

  def update(self):
    lines = Shell.get_command_output(self.command).rsplit('\n')
    lines = [l for l in lines if l]
    if lines:
      self.value = self.process(lines)

class AbstractModuleWithCommonFileSource(AbstractModuleWithFileSource):

  last_update = {}
  all_fields = set()

  def __init__(self):
    self.min_interval = 5
    self.file_content = []
    AbstractModuleWithFileSource.__init__(self)

  def update(self):
    ctime = time.time()
    if ctime - self.last_update[self.file]['time'] >= self.min_interval:
      self.last_update[self.file]['time'] = ctime
      lines = File.get_lines(self.file)
      self.last_update[self.file]['content'] = [l for l in lines if l.split(':')[0] in self.all_fields]
    if self.last_update[self.file]['content']:
      self.value = self.process(self.last_update[self.file]['content'])

  def register(self):
    if not self.file in self.last_update:
      self.last_update[self.file] = {'time': 0, 'content': []}
    self.all_fields.update(self.fields)
    self.last_update[self.file]['time'] = 0
    self.update()

class AbstractModuleMeminfo(AbstractModuleWithCommonFileSource):

  def __init__(self):
    AbstractModuleWithCommonFileSource.__init__(self)

  def pre_init(self):
    self.fields = []
    self.file = '/proc/meminfo'
    self.value = 0
    self.pre_init_meminfo()
    self.register()

  def pre_init_meminfo(self):
    raise NotImplementedError("AbstractModuleMeminfo.pre_init_meminfo() must be implemented")

  def process(self, lines):
    return System.process_meminfo(lines, self.fields)

==> advanced-power-monitor-src_0.5.1-3.tar.gz: advanced-power-monitor-src-0.5.1/src/usr/src/advanced-power-monitor/modules/AbstractModules.py <==
'''
Advanced Power Abstract Module and its subclasses
2008-2009(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from Util import File, Shell, System
import time, os.path

class AbstractModule():

  def __init__(self):
    self.name = self.__class__.__name__
    self.interval = 1000
    self.value = None
    self.available = True
    self.async = False
    self.pre_init()
    self.available = self.available and self.check_available()
    if self.available:
      self.update()

  def pre_init(self):
    raise NotImplementedError("AbstractModule.pre_init() must be implemented")

  def check_available(self):
    raise NotImplementedError("AbstractModule.check_available() must be implemented")

  def update(self):
    raise NotImplementedError("AbstractModule.update() must be implemented")

  def process(self):
    raise NotImplementedError("AbstractModule.process() must be implemented")

  def get_name(self):
    return self.__class__.__name__

  def get_updated(self):
    self.update()
    return self.value

class AbstractModuleWithFileSource(AbstractModule):

  def __init__(self):
    self.file = ''
    AbstractModule.__init__(self)

  def check_available(self):
    return os.path.exists(self.file) and os.path.isfile(self.file)

  def update(self):
    lines = File.get_lines(self.file)
    if lines:
      self.value = self.process(lines)

class AbstractModuleWithShellSource(AbstractModule):

  def __init__(self):
    self.command = ''
    AbstractModule.__init__(self)

  def check_available(self):
    return True

  def update(self):
    lines = Shell.get_command_output(self.command).rsplit('\n')
    lines = [l for l in lines if l]
    if lines:
      self.value = self.process(lines)

class AbstractModuleWithCommonFileSource(AbstractModuleWithFileSource):

  last_update = {}
  all_fields = set()

  def __init__(self):
    self.min_interval = 5
    self.file_content = []
    AbstractModuleWithFileSource.__init__(self)

  def update(self):
    ctime = time.time()
    if ctime - self.last_update[self.file]['time'] >= self.min_interval:
      self.last_update[self.file]['time'] = ctime
      lines = File.get_lines(self.file)
      self.last_update[self.file]['content'] = [l for l in lines if l.split(':')[0] in self.all_fields]
    if self.last_update[self.file]['content']:
      self.value = self.process(self.last_update[self.file]['content'])

  def register(self):
    if not self.file in self.last_update:
      self.last_update[self.file] = {'time': 0, 'content': []}
    self.all_fields.update(self.fields)
    self.last_update[self.file]['time'] = 0
    self.update()

class AbstractModuleMeminfo(AbstractModuleWithCommonFileSource):

  def __init__(self):
    AbstractModuleWithCommonFileSource.__init__(self)

  def pre_init(self):
    self.fields = []
    self.file = '/proc/meminfo'
    self.value = 0
    self.pre_init_meminfo()
    self.register()

  def pre_init_meminfo(self):
    raise NotImplementedError("AbstractModuleMeminfo.pre_init_meminfo() must be implemented")

  def process(self, lines):
    return System.process_meminfo(lines, self.fields)
